package opendap.http.error;

import javax.servlet.http.HttpServletResponse;

/**
 * The resource identified by the request is only capable of generating
 * response entities which have content characteristics not acceptable
 * according to the accept headers sent in the request.<br/>
 *
 * Unless it was a HEAD request, the response SHOULD include an entity
 * containing a list of available entity characteristics and location(s)
 * from which the user or user agent can choose the one most appropriate.
 * The entity format is specified by the media type given in the
 * Content-Type header field. Depending upon the format and the
 * capabilities of the user agent, selection of the most appropriate choice
 * MAY be performed automatically. However, this specification does not
 * define any standard for such automatic selection. <br/>
 *
 * <blockquote>
 *     Note: HTTP/1.1 servers are allowed to return responses which are
 *     not acceptable according to the accept headers sent in the
 *     request. In some cases, this may even be preferable to sending a
 *     406 response. User agents are encouraged to inspect the headers of
 *     an incoming response to determine if it is acceptable.
 * </blockquote>
 * If the response could be unacceptable, a user agent SHOULD temporarily
 * stop receipt of more data and query the user for a decision on further
 * actions.
 */
public class NotAcceptable extends HttpError {

    private static final int _status = HttpServletResponse.SC_NOT_ACCEPTABLE;

    public NotAcceptable(String msg) {
        super(msg);
        super._status = _status;
    }

    public NotAcceptable(String msg, Exception e) {
        super(msg, e);
        super._status = _status;

    }

    public NotAcceptable(String msg, Throwable cause) {
        super(msg, cause);
        super._status = _status;

    }

    public NotAcceptable(Throwable cause) {
        super(cause);
        super._status = _status;
    }

}
